<?php
if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! defined( 'CHERRYCHECKOUT_PLUGIN_ID' ) ) exit;

require_once( CHERRYCHECKOUT_DIR . '/class/CherryCheckoutApi.php' );
require_once( CHERRYCHECKOUT_DIR . '/class/CherryCheckoutWordpressConfig.php' );

wp_enqueue_style('cherrycheckout-settings-style', CHERRYCHECKOUT_URL.'assets/css/settings.css');

$settings = unserialize( get_option( CHERRYCHECKOUT_PLUGIN_ID . '_api_settings' ) );

// Set default settings
if ( ! $settings ) {
	$settings = array(
		'api'				=> 'https://api.cherrycheckout.com/v2',
		'publicKey'			=> '',
		'privateKey'		=> '',
		'cancelStatus'		=> array('wc-cancelled', 'wc-refunded', 'wc-failed'),
	);
}

echo '<h2>'. __( 'configuration_settings', CHERRYCHECKOUT_PLUGIN_ID ) .'</h2>';

echo '<div class="cherrycheckout-notif cherrycheckout-info">';
echo '	<p>'. __( 'configuration_help_to_obtain_api_keys', CHERRYCHECKOUT_PLUGIN_ID ) .' <a href="' . __( 'configuration_developers_url', CHERRYCHECKOUT_PLUGIN_ID ) . '" target="_blank">developers.cherrycheckout.com</a></p>';
echo '	<p>'. __( 'configuration_help_for_invoices_and_stats', CHERRYCHECKOUT_PLUGIN_ID ) .' <a href="' . __( 'configuration_dashboard_url', CHERRYCHECKOUT_PLUGIN_ID ) . '" target="_blank">dashboard.cherrycheckout.com</a></p>';
echo '</div>';

try {
	$me = _resetMe();

	echo '<div class="cherrycheckout-notif cherrycheckout-success"><p><i class="dashicons dashicons-yes"></i> '. __( 'configuration_seems_good', CHERRYCHECKOUT_PLUGIN_ID ) .'</p></div>';

	// If we are in test mode, show it
	if ($me->mode == 'test' && ! WP_DEBUG) {
		echo '<div class="cherrycheckout-notif cherrycheckout-warning"><p><i class="dashicons dashicons-warning"></i> '. __( 'configuration_mode_test', CHERRYCHECKOUT_PLUGIN_ID ) .'</p></div>';
	}
	else if ($me->mode == 'prod' && WP_DEBUG) {
		echo '<div class="cherrycheckout-notif cherrycheckout-warning"><p><i class="dashicons dashicons-warning"></i> '. __( 'configuration_mode_prod', CHERRYCHECKOUT_PLUGIN_ID ) .'</p></div>';
	}

	// Send Wordpress information to API
	try {
		$cherrycheckoutApi = new CherryCheckoutApi($settings['api'], $settings['publicKey'], $settings['privateKey']);

		$values = CherryCheckoutWordpressConfig::get();
		$values['pluginInstalled'] = true;
		$values['pluginInstalledMode'] = $me->mode;
		$cherrycheckoutApi->updateMe( $values );
	}
	catch ( \Exception $ex ) {
		CherryCheckoutLogger::add('[show-settings.php] ERROR : ' . $ex->getMessage(), 310510);
	}
}
catch ( \Exception $ex ) {
	echo '<div class="cherrycheckout-notif cherrycheckout-error"><p><i class="dashicons dashicons-no"></i> '. __( 'configuration_seems_wrong', CHERRYCHECKOUT_PLUGIN_ID ) .'</p></div>';
	CherryCheckoutLogger::add('[show-settings.php] ERROR : ' . $ex->getMessage(), 310520);
}


echo '<table class="form-table">';
echo '	<tbody>';
echo '		<tr valign="top">';
echo '			<th scope="row" class="titledesc">';
echo '				<label for="cherrycheckout_api">'. __( 'configuration_label_api', CHERRYCHECKOUT_PLUGIN_ID ) .'</label>';
echo '			</th>';
echo '			<td class="forminp forminp-text">';
echo '				<input name="cherrycheckout_api" id="cherrycheckout_api" type="text" placeholder="https://" style="width: 360px;" value="'. $settings['api'] .'" />';
echo '			</td>';
echo '		</tr>';

echo '		<tr valign="top">';
echo '			<th scope="row" class="titledesc">';
echo '				<label for="cherrycheckout_publicKey">'. __( 'configuration_label_public_key', CHERRYCHECKOUT_PLUGIN_ID ) .'</label>';
echo '			</th>';
echo '			<td class="forminp forminp-text">';
echo '				<input name="cherrycheckout_publicKey" id="cherrycheckout_publicKey" type="text" placeholder="pk_" style="width: 360px;" value="'. $settings['publicKey'] .'" />';
echo '			</td>';
echo '		</tr>';

echo '		<tr valign="top">';
echo '			<th scope="row" class="titledesc">';
echo '				<label for="cherrycheckout_privateKey">'. __( 'configuration_label_private_key', CHERRYCHECKOUT_PLUGIN_ID ) .'</label>';
echo '			</th>';
echo '			<td class="forminp forminp-text">';
echo '				<input name="cherrycheckout_privateKey" id="cherrycheckout_privateKey" type="text" placeholder="sk_" style="width: 360px;" value="'. $settings['privateKey'] .'" />';
echo '			</td>';
echo '		</tr>';

echo '		<tr valign="top">';
echo '			<th scope="row" class="titledesc">';
echo '				<label>'. __( 'configuration_label_order_status_cancel', CHERRYCHECKOUT_PLUGIN_ID ) .'</label>';
echo '			</th>';
echo '			<td class="forminp">';

// Get order status
$orderStatus = wc_get_order_statuses();
foreach ($orderStatus as $key => $value) {

	if ( in_array( $key, $settings['cancelStatus'] ) ) {
		$checked = 'checked="checked"';
	}
	else {
		$checked = '';
	}

	echo '			<label><input type="checkbox" name="cherrycheckout_cancelStatus_'.$key.'" '.$checked.' /> '.$value.'</label><br />';
}

echo '			</td>';
echo '		</tr>';

echo '	</tbody>';
echo '</table>';