<?php

if (!function_exists('getallheaders'))
{
	function getallheaders()
	{
		$headers = array ();
		foreach ($_SERVER as $name => $value)
		{
			if (substr($name, 0, 5) == 'HTTP_')
			{
				$headers[str_replace(' ', '-', ucwords(strtolower(str_replace('_', ' ', substr($name, 5)))))] = $value;
			}
		}
		return $headers;
	}
}

require_once(dirname(__FILE__).'/../../../wp-config.php');
require_once(dirname(__FILE__).'/../../../wp-admin/includes/plugin.php');

require_once('cherrycheckout.php');
require_once('class/CherryCheckoutApi.php');

if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! defined( 'CHERRYCHECKOUT_PLUGIN_ID' ) ) exit;

class CherryCheckoutWebservice
{
	public function __construct($messageEncrypted, $timestamp)
	{
		$keys = _getApiKeys();
		$hash = CherryCheckoutApi::hashKeys($keys['publicKey'], $keys['privateKey'], $timestamp);

		if ($messageEncrypted != $hash) {
			throw new Exception ('module is not active');
		}

		return true;
	}

	public function resetMe()
	{
		try {
			_resetMe();

			return array(
				'result' => true,
				'message' => 'me reset'
			);
		}
		catch (Exception $ex) {
			return array(
				'result' => false,
				'message' => $ex->getMessage()
			);
		}
	}

	public function getLogs()
	{
		try {
			$logFile = CherryCheckoutLogger::generateLogFile();

			return array(
				'result' => true,
				'message' => $logFile
			);
		}
		catch (\Exception $ex) {
			return array(
				'result' => false,
				'message' => $ex->getMessage()
			);
		}
	}
}

$response = null;

try {
	$headers = getallheaders();
	$authorization = null;
	$timestamp = false;

	// Get headers parameters
	foreach (getallheaders() as $name => $value) {
		if (strtolower($name) == 'authorization') {
			$authorization = explode(':', $value);
		}
		else if (strtolower($name) == 'timestamp') {
			$timestamp = $value;
		}
	}

	// Check authorization parameters
	if (count($authorization) != 2 || !$timestamp) {
		throw new Exception('wrong authorization parameters');
	}

	$messageEncrypted = $authorization[1];
	$webservice = new CherryCheckoutWebservice($messageEncrypted, $timestamp);
}
catch (\Exception $ex) {
	$response = array(
		'result' => false,
		'message' => $ex->getMessage()
	);
}


if (!isset($_GET['action'])) {
	$response = array(
		'result' => false,
		'message' => 'action parameter is missing'
	);
}
elseif (isset($webservice)) {
	switch ($_GET['action'])
	{
		case 'resetMe':
			$response = $webservice->resetMe();
			break;
		case 'getLogs':
			$response = $webservice->getLogs();
			break;
		default:
			$response = array(
				'result' => false,
				'message' => 'action parameter is wrong'
			);
			break;
	}
}

if ($response) {
	echo json_encode($response);
}